@@ -16,7 +16,7 @@ use base qw(Lemonldap::NG::Handler::SharedConf);
 use utf8;
 no utf8;
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.1.2';
 
 # We need just this constant, that's why Portal is 'required' but not 'used'
 *PE_OK = *Lemonldap::NG::Portal::SharedConf::PE_OK;
@@ -140,7 +140,7 @@ sub run ($$) {
     $class->hideCookie;
 
     # Hide user password
-    lmSetHeaderIn( $apacheRequest, Authorization => '' );
+    $class->lmSetHeaderIn( $apacheRequest, Authorization => '' );
     OK;
 }
 
